import dotenv from "dotenv";
import z from "zod";

export function dev() {
  return process.env.NODE_ENV === "development";
}

export function prod() {
  return process.env.NODE_ENV === "production";
}

export function test() {
  return process.env.NODE_ENV === "test";
}

type Zod = typeof z;

export function defineEnv<T>(f: (z: Zod) => z.Schema<T>) {
  const schema = f(z);
  if (process.env.NODE_ENV === "test") {
    process.env.LOG_LEVEL === "debug" && console.log("loading .env.test");
    dotenv.config({ path: ".env.test" });
  }
  process.env.LOG_LEVEL === "debug" && console.log("loading .env");
  dotenv.config({ path: ".env" });

  const parsed = schema.parse(process.env);
  process.env.LOG_LEVEL === "debug" && console.log("parsed env", parsed);
  return parsed;
}
